{% extends "wafer/base_form.html" %}
{% load crispy_forms_tags %}
{% block title %}{{ WAFER_CONFERENCE_NAME }} - Day Trip Insurance{% endblock %}
{% block content %}
<h1>Day Trip Insurance</h1>
{% if not DAYTRIP_INSURANCE_OPEN %}
  <h2 class="alert alert-warning">Registration for insurance has closed</h2>
{% endif %}
<div>
  {% crispy form %}
</div>
{% endblock %}

