/*!
  * Tempus Dominus v6.9.4 (https://getdatepicker.com/)
  * Copyright 2013-2024 Jonathan Peterson
  * Licensed under MIT (https://github.com/Eonasdan/tempus-dominus/blob/master/LICENSE)
  */
(function(g,f){typeof exports==='object'&&typeof module!=='undefined'?f(exports):typeof define==='function'&&define.amd?define(['exports'],f):(g=typeof globalThis!=='undefined'?globalThis:g||self,f((g.tempusDominus=g.tempusDominus||{},g.tempusDominus.locales=g.tempusDominus.locales||{},g.tempusDominus.locales.hy={})));})(this,(function(exports){'use strict';const name = 'hy';
const localization = {
    today: 'Այսօր',
    clear: 'Ջնջել ընտրվածը',
    close: 'Փակել',
    selectMonth: 'Ընտրել ամիս',
    previousMonth: 'Նախորդ ամիս',
    nextMonth: 'Հաջորդ ամիս',
    selectYear: 'Ընտրել տարի',
    previousYear: 'Նախորդ տարի',
    nextYear: 'Հաջորդ տարի',
    selectDecade: 'Ընտրել տասնամյակ',
    previousDecade: 'Նախորդ տասնամյակ',
    nextDecade: 'Հաջորդ տասնամյակ',
    previousCentury: 'Նախորդ դար',
    nextCentury: 'Հաջորդ դար',
    pickHour: 'Ընտրել ժամ',
    incrementHour: 'Ավելացնել ժամ',
    decrementHour: 'Նվազեցնել ժամ',
    pickMinute: 'Ընտրել րոպե',
    incrementMinute: 'Ավելացնել րոպե',
    decrementMinute: 'Նվազեցնել րոպե',
    pickSecond: 'Ընտրել երկրորդը',
    incrementSecond: 'Ավելացնել վայրկյան',
    decrementSecond: 'Նվազեցնել վայրկյան',
    toggleMeridiem: 'Փոփոխել Ժամանակաշրջանը',
    selectTime: 'Ընտրել Ժամ',
    selectDate: 'Ընտրել ամսաթիվ',
    dayViewHeaderFormat: { month: 'long', year: '2-digit' },
    locale: 'hy',
    startOfTheWeek: 1,
    dateFormats: {
        LT: 'H:mm',
        LTS: 'H:mm:ss',
        L: 'dd.MM.yyyy',
        LL: 'd MMMM yyyy թ.',
        LLL: 'd MMMM yyyy թ., H:mm',
        LLLL: 'dddd, d MMMM yyyy թ., H:mm',
    },
    ordinal: (n) => n,
    format: 'L LTS',
};exports.localization=localization;exports.name=name;Object.defineProperty(exports,'__esModule',{value:true});}));