const name = 'ru';

const localization = {
  today: 'Перейти сегодня',
  clear: 'Очистить выделение',
  close: 'Закрыть сборщик',
  selectMonth: 'Выбрать месяц',
  previousMonth: 'Предыдущий месяц',
  nextMonth: 'В следующем месяце',
  selectYear: 'Выбрать год',
  previousYear: 'Предыдущий год',
  nextYear: 'В следующем году',
  selectDecade: 'Выбрать десятилетие',
  previousDecade: 'Предыдущее десятилетие',
  nextDecade: 'Следующее десятилетие',
  previousCentury: 'Предыдущий век',
  nextCentury: 'Следующий век',
  pickHour: 'Выберите час',
  incrementHour: 'Время увеличения',
  decrementHour: 'Уменьшить час',
  pickMinute: 'Выбрать минуту',
  incrementMinute: 'Минута приращения',
  decrementMinute: 'Уменьшить минуту',
  pickSecond: 'Выбрать второй',
  incrementSecond: 'Увеличение секунды',
  decrementSecond: 'Уменьшение секунды',
  toggleMeridiem: 'Переключить период',
  selectTime: 'Выбрать время',
  selectDate: 'Выбрать дату',
  dayViewHeaderFormat: { month: 'long', year: '2-digit' },
  locale: 'ru',
  startOfTheWeek: 1,
  dateFormats: {
    LT: 'H:mm',
    LTS: 'H:mm:ss',
    L: 'dd.MM.yyyy',
    LL: 'd MMMM yyyy г.',
    LLL: 'd MMMM yyyy г., H:mm',
    LLLL: 'dddd, d MMMM yyyy г., H:mm',
  },
  ordinal: (n) => n,
  format: 'L LT',
};

export { localization, name };
