/*!
  * Tempus Dominus v6.9.4 (https://getdatepicker.com/)
  * Copyright 2013-2024 Jonathan Peterson
  * Licensed under MIT (https://github.com/Eonasdan/tempus-dominus/blob/master/LICENSE)
  */
(function(g,f){typeof exports==='object'&&typeof module!=='undefined'?f(exports):typeof define==='function'&&define.amd?define(['exports'],f):(g=typeof globalThis!=='undefined'?globalThis:g||self,f((g.tempusDominus=g.tempusDominus||{},g.tempusDominus.locales=g.tempusDominus.locales||{},g.tempusDominus.locales.ar={})));})(this,(function(exports){'use strict';const name = 'ar';
const localization = {
    today: 'اليوم',
    clear: 'مسح',
    close: 'إغلاق',
    selectMonth: 'اختر الشهر',
    previousMonth: 'الشهر السابق',
    nextMonth: 'الشهر التالي',
    selectYear: 'اختر السنة',
    previousYear: 'العام السابق',
    nextYear: 'العام التالي',
    selectDecade: 'اختر العقد',
    previousDecade: 'العقد السابق',
    nextDecade: 'العقد التالي',
    previousCentury: 'القرن السابق',
    nextCentury: 'القرن التالي',
    pickHour: 'اختر الساعة',
    incrementHour: 'أضف ساعة',
    decrementHour: 'أنقص ساعة',
    pickMinute: 'اختر الدقيقة',
    incrementMinute: 'أضف دقيقة',
    decrementMinute: 'أنقص دقيقة',
    pickSecond: 'اختر الثانية',
    incrementSecond: 'أضف ثانية',
    decrementSecond: 'أنقص ثانية',
    toggleMeridiem: 'تبديل الفترة',
    selectTime: 'اخر الوقت',
    selectDate: 'اختر التاريخ',
    dayViewHeaderFormat: { month: 'long', year: '2-digit' },
    locale: 'ar',
    startOfTheWeek: 1,
    dateFormats: {
        LT: 'HH:mm',
        LTS: 'HH:mm:ss',
        L: 'd/M/yyyy',
        LL: 'd MMMM yyyy',
        LLL: 'd MMMM yyyy HH:mm',
        LLLL: 'dddd d MMMM yyyy HH:mm',
    },
    ordinal: (n) => n,
    format: 'L LT',
};exports.localization=localization;exports.name=name;Object.defineProperty(exports,'__esModule',{value:true});}));