const name = 'hy';

const localization = {
  today: 'Այսօր',
  clear: 'Ջնջել ընտրվածը',
  close: 'Փակել',
  selectMonth: 'Ընտրել ամիս',
  previousMonth: 'Նախորդ ամիս',
  nextMonth: 'Հաջորդ ամիս',
  selectYear: 'Ընտրել տարի',
  previousYear: 'Նախորդ տարի',
  nextYear: 'Հաջորդ տարի',
  selectDecade: 'Ընտրել տասնամյակ',
  previousDecade: 'Նախորդ տասնամյակ',
  nextDecade: 'Հաջորդ տասնամյակ',
  previousCentury: 'Նախորդ դար',
  nextCentury: 'Հաջորդ դար',
  pickHour: 'Ընտրել ժամ',
  incrementHour: 'Ավելացնել ժամ',
  decrementHour: 'Նվազեցնել ժամ',
  pickMinute: 'Ընտրել րոպե',
  incrementMinute: 'Ավելացնել րոպե',
  decrementMinute: 'Նվազեցնել րոպե',
  pickSecond: 'Ընտրել երկրորդը',
  incrementSecond: 'Ավելացնել վայրկյան',
  decrementSecond: 'Նվազեցնել վայրկյան',
  toggleMeridiem: 'Փոփոխել Ժամանակաշրջանը',
  selectTime: 'Ընտրել Ժամ',
  selectDate: 'Ընտրել ամսաթիվ',
  dayViewHeaderFormat: { month: 'long', year: '2-digit' },
  locale: 'hy',
  startOfTheWeek: 1,
  dateFormats: {
    LT: 'H:mm',
    LTS: 'H:mm:ss',
    L: 'dd.MM.yyyy',
    LL: 'd MMMM yyyy թ.',
    LLL: 'd MMMM yyyy թ., H:mm',
    LLLL: 'dddd, d MMMM yyyy թ., H:mm',
  },
  ordinal: (n) => n,
  format: 'L LTS',
};

export { localization, name };
