# Generated by Django 4.2.20 on 2025-03-14 13:50

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bursary", "0004_bursary_attendance_status"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="bursary",
            options={
                "permissions": (
                    ("review_attendance", "Can review attendance requests"),
                ),
                "verbose_name": "bursary request",
            },
        ),
        migrations.AddField(
            model_name="bursary",
            name="partial_contribution",
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name="bursary",
            name="accommodation_status",
            field=models.CharField(
                choices=[
                    ("submitted", "The bursary request has been submitted"),
                    ("ranked", "The bursary request has been ranked"),
                    (
                        "pending",
                        "The bursary request has been granted and is pending your acceptance",
                    ),
                    ("accepted", "The attendee has accepted the bursary grant"),
                    ("denied", "The bursary request has been denied"),
                    ("expired", "The bursary grant has expired"),
                    ("canceled", "The bursary request has been canceled"),
                ],
                default="submitted",
                max_length=32,
            ),
        ),
        migrations.AlterField(
            model_name="bursary",
            name="attendance_status",
            field=models.CharField(
                choices=[
                    ("submitted", "The bursary request has been submitted"),
                    ("ranked", "The bursary request has been ranked"),
                    (
                        "pending",
                        "The bursary request has been granted and is pending your acceptance",
                    ),
                    ("accepted", "The attendee has accepted the bursary grant"),
                    ("denied", "The bursary request has been denied"),
                    ("expired", "The bursary grant has expired"),
                    ("canceled", "The bursary request has been canceled"),
                ],
                default="submitted",
                max_length=32,
            ),
        ),
        migrations.AlterField(
            model_name="bursary",
            name="expenses_status",
            field=models.CharField(
                choices=[
                    ("submitted", "The bursary request has been submitted"),
                    ("ranked", "The bursary request has been ranked"),
                    (
                        "pending",
                        "The bursary request has been granted and is pending your acceptance",
                    ),
                    ("accepted", "The attendee has accepted the bursary grant"),
                    ("denied", "The bursary request has been denied"),
                    ("expired", "The bursary grant has expired"),
                    ("canceled", "The bursary request has been canceled"),
                ],
                default="submitted",
                max_length=32,
            ),
        ),
        migrations.AlterField(
            model_name="bursary",
            name="food_status",
            field=models.CharField(
                choices=[
                    ("submitted", "The bursary request has been submitted"),
                    ("ranked", "The bursary request has been ranked"),
                    (
                        "pending",
                        "The bursary request has been granted and is pending your acceptance",
                    ),
                    ("accepted", "The attendee has accepted the bursary grant"),
                    ("denied", "The bursary request has been denied"),
                    ("expired", "The bursary grant has expired"),
                    ("canceled", "The bursary request has been canceled"),
                ],
                default="submitted",
                max_length=32,
            ),
        ),
        migrations.AlterField(
            model_name="bursary",
            name="travel_status",
            field=models.CharField(
                choices=[
                    ("submitted", "The bursary request has been submitted"),
                    ("ranked", "The bursary request has been ranked"),
                    (
                        "pending",
                        "The bursary request has been granted and is pending your acceptance",
                    ),
                    ("accepted", "The attendee has accepted the bursary grant"),
                    ("denied", "The bursary request has been denied"),
                    ("expired", "The bursary grant has expired"),
                    ("canceled", "The bursary request has been canceled"),
                ],
                default="submitted",
                max_length=32,
            ),
        ),
    ]
