/*!
  * Tempus Dominus v6.9.4 (https://getdatepicker.com/)
  * Copyright 2013-2024 Jonathan Peterson
  * Licensed under MIT (https://github.com/Eonasdan/tempus-dominus/blob/master/LICENSE)
  */
(function(g,f){typeof exports==='object'&&typeof module!=='undefined'?f(exports):typeof define==='function'&&define.amd?define(['exports'],f):(g=typeof globalThis!=='undefined'?globalThis:g||self,f((g.tempusDominus=g.tempusDominus||{},g.tempusDominus.locales=g.tempusDominus.locales||{},g.tempusDominus.locales.ro={})));})(this,(function(exports){'use strict';const name = 'ro';
const localization = {
    today: 'Mergi la ziua de astăzi',
    clear: 'Șterge selecția',
    close: 'Închide calendarul',
    selectMonth: 'Selectează luna',
    previousMonth: 'Luna precedentă',
    nextMonth: 'Luna următoare',
    selectYear: 'Selectează anul',
    previousYear: 'Anul precedent',
    nextYear: 'Anul următor',
    selectDecade: 'Selectează deceniul',
    previousDecade: 'Deceniul precedent',
    nextDecade: 'Deceniul următor',
    previousCentury: 'Secolul precedent',
    nextCentury: 'Secolul următor',
    pickHour: 'Alege ora',
    incrementHour: 'Incrementează ora',
    decrementHour: 'Decrementează ora',
    pickMinute: 'Alege minutul',
    incrementMinute: 'Incrementează minutul',
    decrementMinute: 'Decrementează minutul',
    pickSecond: 'Alege secunda',
    incrementSecond: 'Incrementează secunda',
    decrementSecond: 'Decrementează secunda',
    toggleMeridiem: 'Comută modul AM/PM',
    selectTime: 'Selectează ora',
    selectDate: 'Selectează data',
    dayViewHeaderFormat: { month: 'long', year: '2-digit' },
    locale: 'ro',
    startOfTheWeek: 1,
    dateFormats: {
        LT: 'H:mm',
        LTS: 'H:mm:ss',
        L: 'dd.MM.yyyy',
        LL: 'd MMMM yyyy',
        LLL: 'd MMMM yyyy H:mm',
        LLLL: 'dddd, d MMMM yyyy H:mm',
    },
    ordinal: (n) => n,
    format: 'L LT',
};exports.localization=localization;exports.name=name;Object.defineProperty(exports,'__esModule',{value:true});}));