const name = 'fi';

const localization = {
  today: 'Tänään',
  clear: 'Tyhjennä',
  close: 'Sulje',
  selectMonth: 'Valitse kuukausi',
  previousMonth: 'Edellinen kuukausi',
  nextMonth: 'Seuraava kuukausi',
  selectYear: 'Valitse vuosi',
  previousYear: 'Edellinen vuosi',
  nextYear: 'Seuraava vuosi',
  selectDecade: 'Valitse vuosikymmen',
  previousDecade: 'Edellinen vuosikymmen',
  nextDecade: 'Seuraava vuosikymmen',
  previousCentury: 'Edellinen vuosisata',
  nextCentury: 'Seuraava vuosisata',
  pickHour: 'Valitse tunnit',
  incrementHour: 'Vähennä tunteja',
  decrementHour: 'Lisää tunteja',
  pickMinute: 'Valitse minuutit',
  incrementMinute: 'Vähennä minuutteja',
  decrementMinute: 'Lisää minuutteja',
  pickSecond: 'Valitse sekuntit',
  incrementSecond: 'Vähennä sekunteja',
  decrementSecond: 'Lisää sekunteja',
  toggleMeridiem: 'Vaihda kellonaikaa',
  selectTime: 'Valitse aika',
  selectDate: 'Valise päivä',
  dayViewHeaderFormat: { month: 'long', year: '2-digit' },
  locale: 'fi',
  startOfTheWeek: 1,
  dateFormats: {
    LT: 'HH.mm',
    LTS: 'HH.mm.ss',
    L: 'dd.MM.yyyy',
    LL: 'd. MMMM[ta] yyyy',
    LLL: 'd. MMMM[ta] yyyy, [klo] HH.mm',
    LLLL: 'dddd, d. MMMM[ta] yyyy, [klo] HH.mm',
  },
  ordinal: (n) => `${n}.`,
  format: 'L LT',
};

export { localization, name };
