# Generated by Django 4.2.19 on 2025-03-11 18:03

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("register", "0016_attendee_affiliation"),
    ]

    operations = [
        migrations.AddField(
            model_name="attendee",
            name="country_of_citizenship",
            field=models.CharField(blank=2, max_length=2, null=True),
        ),
        migrations.AddField(
            model_name="attendee",
            name="date_of_birth",
            field=models.DateField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="attendee",
            name="full_legal_name",
            field=models.CharField(blank=True, max_length=256, null=True),
        ),
    ]
